==> calligraplan_3.3.0.orig.tar.xz: calligraplan-3.3.0/src/libs/ui/kptintervaledit.h <==
/* This file is part of the KDE project
   Copyright (C) 2004 - 2010 Dag Andersen <danders@get2net.dk>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
*/

#ifndef KPTINTERVALEDIT_H
#define KPTINTERVALEDIT_H

#include "planui_export.h"

#include "ui_kptintervaleditbase.h"
#include "kptcalendar.h"

#include <KoDialog.h>

namespace KPlato
{

class MacroCommand;

class IntervalEditBase : public QWidget, public Ui::IntervalEditBase
{
public:
    explicit IntervalEditBase(QWidget *parent) : QWidget(parent) {
    setupUi(this);
  }
};


class IntervalEditImpl : public IntervalEditBase {
    Q_OBJECT
public:
    explicit IntervalEditImpl(QWidget *parent);

    QList<TimeInterval*> intervals() const;
    void setIntervals(const QList<TimeInterval*> &intervals);

protected Q_SLOTS:
    void slotClearClicked();
    void slotAddIntervalClicked();
    void slotRemoveIntervalClicked();
    void slotIntervalSelectionChanged();
    void enableButtons();

Q_SIGNALS:
    void changed();
};

class IntervalEdit : public IntervalEditImpl {
    Q_OBJECT
public:
    explicit IntervalEdit(CalendarDay *day, QWidget *parent=0);

};

class PLANUI_EXPORT IntervalEditDialog : public KoDialog
{
    Q_OBJECT
public:
    explicit IntervalEditDialog(Calendar *calendar, const QList<CalendarDay*> &days, QWidget *parent = 0);
    
    explicit IntervalEditDialog(Calendar *calendar, const QList<QDate> &dates, QWidget *parent = 0);

    MacroCommand *buildCommand();
    QList<TimeInterval*> intervals() const { return m_panel->intervals(); }
    
protected Q_SLOTS:
    void slotChanged();
    void slotCalendarRemoved(const KPlato::Calendar *cal);

protected:
    MacroCommand *buildCommand(Calendar *calendar, CalendarDay *day);

private:
    Calendar *m_calendar;
    QList<CalendarDay*> m_days;
    QList<QDate> m_dates;
    IntervalEdit *m_panel;
};

}  //KPlato namespace

#endif // INTERVALEDIT_H

==> calligraplan_4.0.1+dfsg.orig.tar.xz: calligraplan-4.0.1/src/libs/ui/kptintervaledit.h <==
/* This file is part of the KDE project
   SPDX-FileCopyrightText: 2004-2010 Dag Andersen <dag.andersen@kdemail.net>

   SPDX-License-Identifier: LGPL-2.0-or-later
*/

#ifndef KPTINTERVALEDIT_H
#define KPTINTERVALEDIT_H

#include "planui_export.h"

#include "ui_kptintervaleditbase.h"
#include "kptcalendar.h"

#include <KoDialog.h>

namespace KPlato
{

class MacroCommand;

class IntervalEditBase : public QWidget, public Ui::IntervalEditBase
{
public:
    explicit IntervalEditBase(QWidget *parent) : QWidget(parent) {
    setupUi(this);
  }
};


class IntervalEditImpl : public IntervalEditBase {
    Q_OBJECT
public:
    explicit IntervalEditImpl(QWidget *parent);

    QList<TimeInterval*> intervals() const;
    void setIntervals(const QList<TimeInterval*> &intervals);

protected Q_SLOTS:
    void slotClearClicked();
    void slotAddIntervalClicked();
    void slotRemoveIntervalClicked();
    void slotIntervalSelectionChanged();
    void enableButtons();

Q_SIGNALS:
    void changed();
};

class IntervalEdit : public IntervalEditImpl {
    Q_OBJECT
public:
    explicit IntervalEdit(CalendarDay *day, QWidget *parent=nullptr);

};

class PLANUI_EXPORT IntervalEditDialog : public KoDialog
{
    Q_OBJECT
public:
    explicit IntervalEditDialog(Calendar *calendar, const QList<CalendarDay*> &days, QWidget *parent = nullptr);
    
    explicit IntervalEditDialog(Calendar *calendar, const QList<QDate> &dates, QWidget *parent = nullptr);

    MacroCommand *buildCommand();
    QList<TimeInterval*> intervals() const { return m_panel->intervals(); }
    
protected Q_SLOTS:
    void slotChanged();
    void slotCalendarRemoved(const KPlato::Calendar *cal);

protected:
    MacroCommand *buildCommand(Calendar *calendar, CalendarDay *day);

private:
    Calendar *m_calendar;
    QList<CalendarDay*> m_days;
    QList<QDate> m_dates;
    IntervalEdit *m_panel;
};

}  //KPlato namespace

#endif // INTERVALEDIT_H
